.. Beam Corset documentation master file, created by
   sphinx-quickstart on Wed Dec  3 22:35:25 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Beam Corset Documentation
=========================

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   intro
   gen/basic_usage.ipynb
   gen/lenses_and_lens_lists.ipynb
   gen/shifting_ranges_and_selections.ipynb
   gen/beam_constraints.ipynb


.. toctree::
   :maxdepth: 2
   :caption: API Reference

   analysis
   config
   core
   database
   plot
   serialize
   solver

